diff pidgin/gtkthemes.c @ 15857:e4805a4be652

Fix smileys
author Sean Egan <seanegan@gmail.com>
date Tue, 20 Mar 2007 19:17:42 +0000
parents 32c366eeeb99
children 07554cc5d090
line wrap: on
line diff
--- a/pidgin/gtkthemes.c	Tue Mar 20 15:28:29 2007 +0000
+++ b/pidgin/gtkthemes.c	Tue Mar 20 19:17:42 2007 +0000
@@ -1,7 +1,7 @@
 /*
  * Themes for Purple
  *
  * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -264,7 +264,7 @@
 	int l;
 
 	char* probedirs[3];
-	probedirs[0] = g_build_filename(DATADIR, "pixmaps", "purple", "smileys", NULL);
+	probedirs[0] = g_build_filename(DATADIR, "pixmaps", "pidgin", "emotes", NULL);
 	probedirs[1] = g_build_filename(purple_user_dir(), "smileys", NULL);
 	probedirs[2] = 0;
 	for (l=0; probedirs[l]; l++) {
@@ -1,7 +1,7 @@
 /*
- * Themes for Purple
+ * Themes for Pidgin
  *
@@ -1,7 +1,7 @@
  *
- * Purple is the legal property of its developers, whose names are too numerous
+ * Pidgin is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.